"""
Development settings for server project.
"""

import os
import yaml

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

def djangoldp_config():

    """Get DjangoLDP parameters from configuration file"""

    path = os.path.join(BASE_DIR, 'packages.yml')
    with open(path, 'r') as f:
        content = yaml.safe_load(f)
        config = content.get('server', {})
        try:
            config['packages'] = list(content.get('ldppackages').keys())
        except AttributeError:
            config['packages'] = []
        return config


DJANGOLDP_PACKAGES = djangoldp_config().get('packages', [])

SECRET_KEY = 'wr1tfli=&(oervg-g8_6*zlrnny=yha^+smg$zq@h@#9lmi%p2'
DEBUG = True
ALLOWED_HOSTS = []

# Application definition

WSGI_APPLICATION = 'server.wsgi.application'

INSTALLED_APPS = list(DJANGOLDP_PACKAGES)

INSTALLED_APPS.extend([
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'djangoldp',
    'guardian'
])

ROOT_URLCONF = 'server.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [os.path.join(BASE_DIR, 'templates')],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

# Database

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
    }
}

# Authentication

AUTH_PASSWORD_VALIDATORS = []
AUTH_USER_MODEL = 'djangoldp_account.LDPUser'
LOGIN_REDIRECT_URL = '/'

if 'djangoldp_account' in INSTALLED_APPS:
    LOGIN_URL = '/auth/login/'
    OIDC_USERINFO = 'djangoldp_account.settings.userinfo'
    OIDC_REGISTRATION_ENDPOINT_REQ_TOKEN = False
    OIDC_REGISTRATION_ENDPOINT_ALLOW_HTTP_ORIGIN = True
    OIDC_IDTOKEN_SUB_GENERATOR = 'djangoldp_account.settings.sub_generator'
    OIDC_IDTOKEN_EXPIRE = 60 * 60 * 1600
    AUTH_USER_MODEL = 'djangoldp_account.LDPUser'
    MIDDLEWARE = [
        'django.middleware.security.SecurityMiddleware',
        'django.contrib.sessions.middleware.SessionMiddleware',
        'django.middleware.common.CommonMiddleware',
        'django.middleware.csrf.CsrfViewMiddleware',
        'django.contrib.auth.middleware.AuthenticationMiddleware',
        'django.contrib.messages.middleware.MessageMiddleware',
        'django.middleware.clickjacking.XFrameOptionsMiddleware',
        'djangoldp_account.auth.middleware.JWTUserMiddleware'
    ]
    AUTHENTICATION_BACKENDS = [
        'djangoldp_account.auth.backends.EmailOrUsernameAuthBackend',
        'guardian.backends.ObjectPermissionBackend',
        'djangoldp_account.auth.backends.ExternalUserBackend'
    ]
else:
    MIDDLEWARE = [
        'django.middleware.security.SecurityMiddleware',
        'django.contrib.sessions.middleware.SessionMiddleware',
        'django.middleware.common.CommonMiddleware',
        'django.middleware.csrf.CsrfViewMiddleware',
        'django.contrib.auth.middleware.AuthenticationMiddleware',
        'django.contrib.messages.middleware.MessageMiddleware',
        'django.middleware.clickjacking.XFrameOptionsMiddleware',
    ]
    AUTHENTICATION_BACKENDS = ['django.contrib.auth.backends.ModelBackend', 'guardian.backends.ObjectPermissionBackend']

if 'djangoldp_notification' in INSTALLED_APPS:
    MIDDLEWARE.append('djangoldp_notification.middlewares.CurrentUserMiddleware')

USER_ANONYMOUS_PERMISSIONS=['add', 'view']
USER_AUTHENTICATED_PERMISSIONS=['view', 'add']
USER_OWNER_PERMISSIONS=['view', 'add', 'change']

GROUP_ANONYMOUS_PERMISSIONS=['view']
GROUP_AUTHENTICATED_PERMISSIONS=['view', 'add', 'change']
GROUP_OWNER_PERMISSIONS=['view', 'add', 'change']

ANONYMOUS_USER_NAME = None

# Internationalization

LANGUAGE_CODE = 'fr-fr'
TIME_ZONE = 'Europe/Paris'
USE_I18N = True
USE_L10N = True
USE_TZ = True

# Static files (CSS, JavaScript, Images)

APPEND_SLASH = False
SITE_URL = djangoldp_config().get('site_url', 'http://localhost:8000')
BASE_URL = SITE_URL
STATIC_URL = '/static/'
STATIC_DIR = os.path.join(BASE_DIR, 'static')
STATIC_ROOT = os.path.join(BASE_DIR, 'staticfiles')
STATICFILES_DIRS = [os.path.join(BASE_DIR, 'static'), ]
MEDIA_URL = '/media/'
MEDIA_ROOT = os.path.join(BASE_DIR, 'media')
MEDIAFILES_DIRS = [os.path.join(BASE_DIR, 'media'), ]
LDP_RDF_CONTEXT = 'https://cdn.happy-dev.fr/owl/hdcontext.jsonld'

# Chat

PROSODY_HTTP_URL = djangoldp_config().get('xmpp_url')
JABBER_DEFAULT_HOST = djangoldp_config().get('jabber_host')

# Email

EMAIL_BACKEND = "django.core.mail.backends.console.EmailBackend"

if DEBUG:
    EMAIL_HOST = 'localhost'
    EMAIL_PORT = 1025
    EMAIL_HOST_USER = ''
    EMAIL_HOST_PASSWORD = ''
    EMAIL_USE_TLS = False
    DEFAULT_FROM_EMAIL = 'testing@example.com'

"""
EMAIL_BACKEND = 'django.core.mail.backends.smtp.EmailBackend'
EMAIL_HOST_USER = ''
EMAIL_HOST_PASSWORD = ''
EMAIL_HOST = ''
EMAIL_USE_TLS = True
EMAIL_PORT = 587
DEFAULT_FROM_EMAIL = ''
"""

# Registration

ACCOUNT_ACTIVATION_DAYS = 3  # days
REGISTRATION_FIELDS = ('first_name', 'last_name', 'email', 'username', 'password1', 'password2')
